@@ -84,7 +84,9 @@ class ObserverContainer(ABC):
         return sum(observer.observation_size for observer in self._observers)
 
     @final
-    def _build_observers(self) -> list[LocalObserver | GlobalObserver]:
+    def _build_observers(
+        self,
+    ) -> list[LocalObserver | GlobalObserver]:
         """
         :return: List of instantiated observers.
         """
